@@ -2,8 +2,5 @@
 # Mail: zhyx12@gmail.com
 # ----------------------------------------------
 from .builder import build_trainer, build_validator, TRAINER, VALIDATOR
-from trainer import BaseTrainer
-from validator import BaseValidator
-
-if __name__ == "__main__":
-    pass
+from .trainer import BaseTrainer
+from .validator import BaseValidator
