@@ -3,8 +3,8 @@
 # ----------------------------------------------
 from mmcv.utils import Registry, build_from_cfg
 
-TRAINER = Registry('trainer')
-VALIDATOR = Registry('validator')
+TRAINER = Registry('fastda_trainer')
+VALIDATOR = Registry('fastda_validator')
 
 
 def build_trainer(cfg, default_args=None):
