@@ -3,10 +3,21 @@
 # ----------------------------------------------
 import torch.utils.tensorboard as tb
 from mmcv.runner import get_dist_info
+from types import FunctionType
 
 ROOT_TB_WRITER = []
 
 
+class EmptySummaryWriter(object):
+    def __init__(self, *args, **kwargs):
+        funcs = [attr for attr in dir(tb.SummaryWriter) if
+                 callable(getattr(tb.SummaryWriter, attr)) and not attr.startswith('_')]
+        for func in funcs:
+            func_code = compile('def {}(*func_args,**func_kwargs): pass'.format(func), "<string>", "exec")
+            func_object = FunctionType(func_code.co_consts[0], globals(), func)
+            self.__setattr__(func, func_object)
+
+
 def get_root_writer(log_dir=None):
     rank, _ = get_dist_info()
     if rank == 0:
@@ -22,4 +33,4 @@ def get_root_writer(log_dir=None):
             else:
                 raise RuntimeError('You have initialized the tensorboard writer before')
     else:
-        return None
+        return EmptySummaryWriter()
